Set a key on a Wincred keyring
Arguments
- service
Service name. Must not be empty.
- username
Username. Might be empty.
- password
The key text to store.
Check if we are using the default keyring.
If yes, then just store the key and we are done.
Otherwise check if keyring exists.
If not, error and finish.
If yes, check if it is locked.
If yes, unlock it.
Encrypt the key with the AES key, and store it.
If required, an encoding can be specified using either an R option (
keyring.encoding_windows) or environment variable (KEYRING_ENCODING_WINDOWS). To set, use one of:options(keyring.encoding_windows = 'encoding-type')Sys.setenv("KEYRING_ENCODING_WINDOWS" = 'encoding-type')For a list of valid encodings, use
iconvlist()